@@ -1,16 +1,16 @@
-#!/usr/local/ActivePerl-5.8/bin/perl -w
+#!/usr/local/ActivePerl-5.8/bin/perl
 use strict;
 
 use Net::RDEP;
 use XML::Idiom;
 use Data::Dumper;
 
-my $RDEP_HOST='208.221.18.61';
-my $RDEP_USER='open';
-my $RDEP_PASS='op3n=9!';
+my $RDEP_HOST='172.16.3.10';
+my $RDEP_USER='rdep';
+my $RDEP_PASS='rd3p123';
 my $RDEP_TYPE='subscription';
 
-my $RDEP_POLL_INTERVAL=10;
+my $RDEP_POLL_INTERVAL=5;
 
 #
 # Obviously, we'll want to do some *real* event processing here...
@@ -31,8 +31,8 @@ $r->Server($RDEP_HOST);
 $r->Type($RDEP_TYPE);
 
 my $idiom = XML::Idiom->new();
-print "Checking Subscription\n";
-while(sleep $RDEP_POLL_INTERVAL) {
+do {
+	print "Checking Subscription\n";
 	my $idiom_xml = $r->get;
 	if (defined($r->error)) {
 		# probably an HTTP problem at this point
@@ -59,6 +59,5 @@ while(sleep $RDEP_POLL_INTERVAL) {
 		print "No events\n";
 	}
 	print "Sleeping...\n";
-	#sleep $RDEP_POLL_INTERVAL;
-}
+} while(sleep $RDEP_POLL_INTERVAL);
 $r->close;
